@@ -27,10 +27,11 @@ module R10K
     class GlobalInitializer < BaseInitializer
       def call
         with_setting(:purgedirs) do |_|
-          logger.warn("the purgedirs key in r10k.yaml is deprecated. it is currently ignored.")
+          logger.warn(_("the purgedirs key in r10k.yaml is deprecated. it is currently ignored."))
         end
 
         with_setting(:cachedir) { |value| R10K::Git::Cache.settings[:cache_root] = value }
+        with_setting(:cachedir) { |value| R10K::Forge::ModuleRelease.settings[:cache_root] = value }
 
         with_setting(:git) { |value| GitInitializer.new(value).call }
         with_setting(:forge) { |value| ForgeInitializer.new(value).call }
@@ -42,13 +43,15 @@ module R10K
         with_setting(:provider) { |value| R10K::Git.provider = value }
         with_setting(:username) { |value| R10K::Git.settings[:username] = value }
         with_setting(:private_key) { |value| R10K::Git.settings[:private_key] = value }
+        with_setting(:proxy) { |value| R10K::Git.settings[:proxy] = value }
+        with_setting(:repositories) { |value| R10K::Git.settings[:repositories] = value }
       end
     end
 
     class ForgeInitializer < BaseInitializer
       def call
         with_setting(:baseurl) { |value| PuppetForge.host = value }
-        with_setting(:proxy) { |value| PuppetForge::V3::Base.conn.proxy(value) }
+        with_setting(:proxy) { |value| PuppetForge::Connection.proxy = value }
       end
     end
   end
