@@ -19,6 +19,10 @@ describe R10K::Action::Deploy::Environment do
       described_class.new({puppetfile: true}, [])
     end
 
+    it "can accept a no-force option" do
+      described_class.new({:'no-force' => true}, [])
+    end
+
     it "normalizes environment names in the arg vector"
   end
 
@@ -53,6 +57,14 @@ describe R10K::Action::Deploy::Environment do
       end
     end
 
+    describe "with no-force" do
+      subject { described_class.new({ config: "/some/nonexistent/path", puppetfile: true, :'no-force' => true}, %w[first]) }
+
+      it "tries to preserve local modifications" do
+        expect(subject.force).to equal(false)
+      end
+    end
+
     describe "purge_levels" do
       let(:settings) { { deploy: { purge_levels: purge_levels } } }
 
